@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #include <config.h>
@@ -28,17 +28,10 @@
 
 #include "yelp-cache.h"
 #include "yelp-window.h"
-#include "yelp-section.h"
-#include "yelp-scrollkeeper.h"
-#include "yelp-man.h"
-#include "yelp-info.h"
+#include "yelp-theme.h"
+#include "yelp-toc-pager.h"
 #include "yelp-base.h"
 
-typedef struct {
-	YelpBase    *base;
-	GtkTreeIter *parent;
-} ForeachData;
-
 struct _YelpBasePriv {
 	GNode  *toc_tree;
 
@@ -46,7 +39,6 @@ struct _YelpBasePriv {
 	GSList *windows;
 };
 
-
 static void           yelp_base_init                (YelpBase       *base);
 static void           yelp_base_class_init          (YelpBaseClass  *klass);
 static void           yelp_base_new_window_cb       (YelpWindow     *window,
@@ -64,17 +56,10 @@ impl_Yelp_newWindow (PortableServer_Servant  servant,
 		     CORBA_Environment      *ev)
 {
 	YelpBase  *yelp_base;
-	GtkWidget *window;
 	
 	yelp_base = YELP_BASE (bonobo_object (servant));
-	
-	window = yelp_base_new_window (yelp_base);
 
-	gtk_widget_show_all (window);
-
-	if (url && strcmp (url, "")) {
-		yelp_window_open_uri (YELP_WINDOW (window), url);
-	}
+	yelp_base_new_window (yelp_base, url);
 }
 
 static GNOME_Yelp_WindowList *
@@ -124,6 +109,7 @@ yelp_base_init (YelpBase *base)
         base->priv     = priv;
 
 	yelp_cache_init ();
+	yelp_theme_init ();
 }
 
 static void
@@ -145,7 +131,7 @@ yelp_base_new_window_cb (YelpWindow *window, YelpBase *base)
 	g_return_if_fail (YELP_IS_WINDOW (window));
 	g_return_if_fail (YELP_IS_BASE (base));
 	
-	new_window = yelp_base_new_window (base);
+	new_window = yelp_base_new_window (base, NULL);
 	
 	gtk_widget_show_all (new_window);
 }
@@ -175,19 +161,24 @@ yelp_base_new (void)
         base = g_object_new (YELP_TYPE_BASE, NULL);
 	priv = base->priv;
 	
+	yelp_toc_pager_init ();
+
+	/*
 	yelp_scrollkeeper_init (priv->toc_tree, &priv->index);
 	yelp_man_init (base->priv->toc_tree, &priv->index);
 	yelp_info_init (base->priv->toc_tree, &priv->index);
 	
 	priv->index = g_list_sort (priv->index, yelp_section_compare);
+	*/
 
         return base;
 }
 
 GtkWidget *
-yelp_base_new_window (YelpBase *base)
+yelp_base_new_window (YelpBase *base, const gchar *str_uri)
 {
 	YelpBasePriv *priv;
+	YelpURI      *uri;
 	GtkWidget    *window;
         
         g_return_val_if_fail (YELP_IS_BASE (base), NULL);
@@ -206,6 +197,16 @@ yelp_base_new_window (YelpBase *base)
 			  G_CALLBACK (yelp_base_new_window_cb),
 			  base);
 
+
+	gtk_widget_show_all (window);
+
+	if (str_uri && strcmp (str_uri, ""))
+		uri = yelp_uri_new (str_uri);
+	else
+		uri = yelp_uri_new ("toc:");
+
+	yelp_window_open_uri (YELP_WINDOW (window), uri);
+
 	return window;
 }
 
