@@ -38,6 +38,7 @@
 #include "yelp-error.h"
 #include "yelp-db-pager.h"
 #include "yelp-toc-pager.h"
+#include "yelp-theme.h"
 
 #define YELP_NAMESPACE "http://www.gnome.org/yelp/ns"
 
@@ -206,12 +207,14 @@ db_pager_process (YelpPager *pager)
     xsltStylesheetPtr       stylesheet;
     xsltTransformContextPtr tctxt;
 
+    gchar *p_doc_name, *p_doc_path;
+
     YelpDBPagerPriv *priv = YELP_DB_PAGER (pager)->priv;
 
     gchar        *uri_slash;
     gchar        *doc_name;
     gchar        *doc_path;
-    const gchar  *params[15];
+    const gchar  *params[21];
 
     g_return_val_if_fail (pager != NULL, FALSE);
     g_return_val_if_fail (YELP_IS_DB_PAGER (pager), FALSE);
@@ -258,19 +261,25 @@ db_pager_process (YelpPager *pager)
 
     walker_walk_xml (walker);
 
+    yelp_pager_set_state  (pager, YELP_PAGER_STATE_CONTENTS);
+    g_signal_emit_by_name (pager, "contents");
+
     while (gtk_events_pending ())
 	gtk_main_iteration ();
 
     uri_slash = g_strrstr (uri_str, "/");
-    doc_name  = g_strndup (uri_str, uri_slash - uri_str + 1);
-    doc_path  = g_strdup  (uri_slash + 1);
+    doc_name  = g_strdup  (uri_slash + 1);
+    doc_path  = g_strndup (uri_str, uri_slash - uri_str + 1);
+
+    p_doc_name = g_strconcat("\"", doc_name, "\"", NULL);
+    p_doc_path = g_strconcat("\"file://", doc_path, "/\"", NULL);
 
     params[0]  = "doc_name";
-    params[1]  = g_strconcat("\"", doc_name, "\"", NULL) ;
+    params[1]  = p_doc_name;
     params[2]  = "doc_path";
-    params[3]  = g_strconcat("\"file://", doc_path, "/\"", NULL) ;
+    params[3]  = p_doc_path;
     params[4]  = "stylesheet_path";
-    params[5]  = g_strconcat("\"file://", DB_STYLESHEET_PATH, "/\"", NULL) ;
+    params[5]  = "\"file://" DB_STYLESHEET_PATH "/\"";
     params[6]  = "chunk_depth";
     params[7]  = "2";
     params[8]  = "html_extension";
@@ -278,8 +287,14 @@ db_pager_process (YelpPager *pager)
     params[10] = "resolve_xref_chunk";
     params[11] = "0";
     params[12] = "mediaobject_path";
-    params[13] = doc_path;
-    params[14] = NULL;
+    params[13] = p_doc_path;
+    params[14] = "color_gray_background";
+    params[15] = yelp_theme_get_gray_background ();
+    params[16] = "color_gray_border";
+    params[17] = yelp_theme_get_gray_border ();
+    params[18] = "admon_graphics_path";
+    params[19] = "\"file://" DATADIR "/yelp/icons/\"";
+    params[20] = NULL;
 
     stylesheet = xsltParseStylesheetFile (DB_STYLESHEET);
     tctxt      = xsltNewTransformContext (stylesheet,
@@ -303,6 +318,8 @@ db_pager_process (YelpPager *pager)
 			     NULL, NULL,
 			     tctxt);
 
+    g_free (p_doc_name);
+    g_free (p_doc_path);
     xmlFreeDoc (doc);
     xsltFreeStylesheet (stylesheet);
     xmlFreeParserCtxt (ctxt);
@@ -310,7 +327,7 @@ db_pager_process (YelpPager *pager)
     g_free (doc_name);
     g_free (doc_path);
 
-    yelp_pager_set_state (pager, YELP_PAGER_STATE_FINISH);
+    yelp_pager_set_state (pager, YELP_PAGER_STATE_FINISHED);
     g_signal_emit_by_name (pager, "finish");
 
     g_object_unref (pager);
@@ -379,7 +396,9 @@ xslt_yelp_document (xsltTransformContextPtr ctxt,
 		    xsltStylePreCompPtr     comp)
 {
     GError  *error;
+    YelpPage *page;
     xmlChar *page_id = NULL;
+    xmlChar *page_title = NULL;
     xmlChar *page_buf;
     gint     buf_size;
     YelpPager *pager;
@@ -387,6 +406,7 @@ xslt_yelp_document (xsltTransformContextPtr ctxt,
     const char *old_outfile;
     xmlDocPtr   new_doc, old_doc;
     xmlNodePtr  old_insert;
+    xmlNodePtr  cur;
 
     if (!ctxt || !node || !inst || !comp)
 	return;
@@ -438,8 +458,39 @@ xslt_yelp_document (xsltTransformContextPtr ctxt,
     ctxt->output     = old_doc;
     ctxt->insert     = old_insert;
 
-    // FIXME
-    yelp_pager_add_page (pager, page_id, g_strdup ("FIXME"), page_buf);
+    page_title = xml_get_title (node);
+
+    if (!page_title)
+	page_title = g_strdup ("FIXME");
+
+    page = g_new0 (YelpPage, 1);
+
+    page->id    = page_id;
+    page->title = page_title;
+    page->chunk = page_buf;
+
+    cur = xmlDocGetRootElement (new_doc);
+    for (cur = cur->children; cur; cur = cur->next) {
+	if (!xmlStrcmp (cur->name, (xmlChar *) "head")) {
+	    for (cur = cur->children; cur; cur = cur->next) {
+		if (!xmlStrcmp (cur->name, (xmlChar *) "link")) {
+		    xmlChar *rel = xmlGetProp (cur, "rel");
+
+		    if (!xmlStrcmp (rel, (xmlChar *) "Previous"))
+			page->prev = xmlGetProp (cur, "href");
+		    else if (!xmlStrcmp (rel, (xmlChar *) "Next"))
+			page->next = xmlGetProp (cur, "href");
+		    else if (!xmlStrcmp (rel, (xmlChar *) "Top"))
+			page->toc = xmlGetProp (cur, "href");
+
+		    xmlFree (rel);
+		}
+	    }
+	    break;
+	}
+    }
+
+    yelp_pager_add_page (pager, page);
     g_signal_emit_by_name (pager, "page", page_id);
 
     while (gtk_events_pending ())
@@ -482,8 +533,12 @@ walker_walk_xml (DBWalker *walker)
 	title = xml_get_title (walker->cur);
 
 	if (id) {
-	    gtk_tree_store_append (GTK_TREE_STORE (priv->sects),
-				   &iter, walker->iter);
+	    if (xml_is_info (walker->cur))
+		gtk_tree_store_prepend (GTK_TREE_STORE (priv->sects),
+					&iter, walker->iter);
+	    else
+		gtk_tree_store_append (GTK_TREE_STORE (priv->sects),
+				       &iter, walker->iter);
 
 	    gtk_tree_store_set (GTK_TREE_STORE (priv->sects),
 				&iter,
@@ -545,7 +600,7 @@ xml_get_title (xmlNodePtr node)
 
     if (xml_is_info (node))
 	title = g_strdup (_("Titlepage"));
-    else if (node->parent->type == XML_DOCUMENT_NODE)
+    else if (node->parent && node->parent->type == XML_DOCUMENT_NODE)
 	title = g_strdup (_("Contents"));
     else {
 	for (cur = node->children; cur; cur = cur->next) {
